Given the mean direction of a group of individuals, leader_direction_group
shifts the coordinate system to a new origin at the group centroid and
rotates the coordinate system by the mean direction to return each
individual's position along the mean direction, representing leadership in
terms of the front-back position in each group's mean direction. Relocation
data should be in two columns representing the X and Y coordinates, or in a
geometry column prepared by the helper function get_geometry().
Usage
leader_direction_group(
DT = NULL,
group_direction = "group_direction",
coords = NULL,
group = "group",
crs = NULL,
geometry = "geometry",
return_rank = TRUE,
ties.method = NULL
)Arguments
- DT
input data.table with group direction columns generated by
direction_groupand centroid columns generated bycentroid_group- group_direction
group_direction column name generated using
direction_group, default 'group_direction'- coords
character vector of X coordinate and Y coordinate column names. Note: the order is assumed X followed by Y column names
- group
group column name, generated by
group_pts, default 'group'- crs
numeric or character defining the coordinate reference system to be passed to sf::st_crs. For example, either
crs = "EPSG:32736"orcrs = 32736. Used only if coords are provided, see details under Interface- geometry
simple feature geometry list column name, generated by
get_geometry(). Default 'geometry', see details under Interface- return_rank
logical if rank distance should also be returned, default TRUE
- ties.method
Value
leader_direction_group returns the input DT appended with a
position_group_direction column indicating the position along the group
direction in the units of the crs and, optionally when return_rank = TRUE, a rank_position_group_direction column indicating the ranked
position along the group direction.
A message is returned when position_group_direction or
rank_position_group_direction columns already exist in the input DT,
because they will be overwritten.
See details for appending outputs using modify-by-reference in the FAQ.
Details
The function expects a data.table with relocation data appended with a
group_direction column from direction_group() and group centroid columns
from centroid_group().
The DT must be a data.table. If your data is a data.frame, you can
convert it by reference using data.table::setDT() or by reassigning using
data.table::data.table().
The group_direction argument expects the names of columns in DT which
correspond to the mean group direction generated by direction_group(). The
mean group direction column is expected in units of radians. The
return_rank argument controls if the rank of each individual's distance to
the group centroid is also returned. If return_rank is TRUE, the group
argument is required to specify the group column generated by group_pts().
The ties.method argument is passed to data.table::frank(), see details at
?data.table::frank().
See below under "Interface" for details on providing coordinates.
Interface
Two interfaces are available for providing coordinates:
Provide
coordsandcrs. Thecoordsargument expects the names of the X and Y coordinate columns. Thecrsargument expects a character string or numeric defining the coordinate reference system to be passed to sf::st_crs. For example, for UTM zone 36S (EPSG 32736), the crs argument iscrs = "EPSG:32736"orcrs = 32736. See https://spatialreference.org for a list of EPSG codes.(New!) Provide
geometry. Thegeometryargument allows the user to supply ageometrycolumn that represents the coordinates as a simple feature geometry list column. This interface expects the user to prepare their input DT withget_geometry(). To use this interface, leave thecoordsandcrsargumentsNULL, and the default argument forgeometry('geometry') will be used directly.
References
See examples of measuring leadership along group direction (also called forefront index):
See also
direction_group, centroid_group
Other Leadership functions:
direction_to_leader(),
leader_edge_delay()
Other Direction functions:
direction_group(),
direction_polarization(),
direction_step(),
direction_to_centroid(),
direction_to_leader(),
edge_alignment(),
edge_delay(),
edge_direction(),
edge_zones(),
leader_edge_delay()
Examples
# Load data.table
library(data.table)
# Read example data
DT <- fread(system.file("extdata", "DT.csv", package = "spatsoc"))
# Cast the character column to POSIXct
DT[, datetime := as.POSIXct(datetime, tz = 'UTC')]
#> ID X Y datetime population
#> <char> <num> <num> <POSc> <int>
#> 1: A 715851.4 5505340 2016-11-01 00:00:54 1
#> 2: A 715822.8 5505289 2016-11-01 02:01:22 1
#> 3: A 715872.9 5505252 2016-11-01 04:01:24 1
#> 4: A 715820.5 5505231 2016-11-01 06:01:05 1
#> 5: A 715830.6 5505227 2016-11-01 08:01:11 1
#> ---
#> 14293: J 700616.5 5509069 2017-02-28 14:00:54 1
#> 14294: J 700622.6 5509065 2017-02-28 16:00:11 1
#> 14295: J 700657.5 5509277 2017-02-28 18:00:55 1
#> 14296: J 700610.3 5509269 2017-02-28 20:00:48 1
#> 14297: J 700744.0 5508782 2017-02-28 22:00:39 1
# Temporal grouping
group_times(DT, datetime = 'datetime', threshold = '20 minutes')
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
# Spatial grouping with timegroup
group_pts(DT, threshold = 50, id = 'ID',
coords = c('X', 'Y'), timegroup = 'timegroup')
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group
#> <int>
#> 1: 1
#> 2: 2
#> 3: 3
#> 4: 4
#> 5: 5
#> ---
#> 116: 8
#> 117: 9
#> 118: 10
#> 119: 11
#> 120: 40
# Calculate direction at each step
direction_step(
DT = DT,
id = 'ID',
coords = c('X', 'Y'),
crs = 32736
)
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group direction
#> <int> <units>
#> 1: 1 1.4903118 [rad]
#> 2: 2 1.7942728 [rad]
#> 3: 3 0.9220273 [rad]
#> 4: 4 -1.7726867 [rad]
#> 5: 5 -2.3533764 [rad]
#> ---
#> 116: 8 2.6583955 [rad]
#> 117: 9 -1.4177958 [rad]
#> 118: 10 0.5336646 [rad]
#> 119: 11 -1.0819257 [rad]
#> 120: 40 NA [rad]
# Calculate group centroid
centroid_group(DT, coords = c('X', 'Y'))
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group direction centroid_X centroid_Y
#> <int> <units> <num> <num>
#> 1: 1 1.4903118 [rad] 696214.3 5508342
#> 2: 2 1.7942728 [rad] 696228.1 5508344
#> 3: 3 0.9220273 [rad] 696760.4 5508245
#> 4: 4 -1.7726867 [rad] 696965.7 5508380
#> 5: 5 -2.3533764 [rad] 696074.7 5508214
#> ---
#> 116: 8 2.6583955 [rad] 696952.5 5508004
#> 117: 9 -1.4177958 [rad] 697014.8 5507923
#> 118: 10 0.5336646 [rad] 697015.8 5507916
#> 119: 11 -1.0819257 [rad] 697285.0 5508368
#> 120: 40 NA [rad] 696620.8 5508731
# Calculate group direction
direction_group(DT)
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group direction centroid_X centroid_Y group_direction
#> <int> <units> <num> <num> <units>
#> 1: 1 1.4903118 [rad] 696214.3 5508342 0.5997289 [rad]
#> 2: 2 1.7942728 [rad] 696228.1 5508344 1.7285069 [rad]
#> 3: 3 0.9220273 [rad] 696760.4 5508245 0.9679820 [rad]
#> 4: 4 -1.7726867 [rad] 696965.7 5508380 -1.7070067 [rad]
#> 5: 5 -2.3533764 [rad] 696074.7 5508214 -0.8348445 [rad]
#> ---
#> 116: 8 2.6583955 [rad] 696952.5 5508004 2.4662821 [rad]
#> 117: 9 -1.4177958 [rad] 697014.8 5507923 -2.9981952 [rad]
#> 118: 10 0.5336646 [rad] 697015.8 5507916 0.5103765 [rad]
#> 119: 11 -1.0819257 [rad] 697285.0 5508368 -1.1444566 [rad]
#> 120: 40 NA [rad] 696620.8 5508731 NA [rad]
# Calculate leader in terms of position along group direction
leader_direction_group(DT, coords = c('X', 'Y'), crs = 32736)
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group direction centroid_X centroid_Y group_direction
#> <int> <units> <num> <num> <units>
#> 1: 1 1.4903118 [rad] 696214.3 5508342 0.5997289 [rad]
#> 2: 2 1.7942728 [rad] 696228.1 5508344 1.7285069 [rad]
#> 3: 3 0.9220273 [rad] 696760.4 5508245 0.9679820 [rad]
#> 4: 4 -1.7726867 [rad] 696965.7 5508380 -1.7070067 [rad]
#> 5: 5 -2.3533764 [rad] 696074.7 5508214 -0.8348445 [rad]
#> ---
#> 116: 8 2.6583955 [rad] 696952.5 5508004 2.4662821 [rad]
#> 117: 9 -1.4177958 [rad] 697014.8 5507923 -2.9981952 [rad]
#> 118: 10 0.5336646 [rad] 697015.8 5507916 0.5103765 [rad]
#> 119: 11 -1.0819257 [rad] 697285.0 5508368 -1.1444566 [rad]
#> 120: 40 NA [rad] 696620.8 5508731 NA [rad]
#> position_group_direction rank_position_group_direction
#> <num> <num>
#> 1: -7.7690645 5
#> 2: 22.0744878 1
#> 3: -24.7063051 5
#> 4: 8.9025813 3
#> 5: -0.2458479 2
#> ---
#> 116: -21.9798928 6
#> 117: -31.1746472 6
#> 118: 22.8303115 1
#> 119: 26.1390093 1
#> 120: NA NA
# Or, using the new geometry interface
get_geometry(DT, coords = c('X', 'Y'), crs = 32736)
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group direction centroid_X centroid_Y group_direction
#> <int> <units> <num> <num> <units>
#> 1: 1 1.4903118 [rad] 696214.3 5508342 0.5997289 [rad]
#> 2: 2 1.7942728 [rad] 696228.1 5508344 1.7285069 [rad]
#> 3: 3 0.9220273 [rad] 696760.4 5508245 0.9679820 [rad]
#> 4: 4 -1.7726867 [rad] 696965.7 5508380 -1.7070067 [rad]
#> 5: 5 -2.3533764 [rad] 696074.7 5508214 -0.8348445 [rad]
#> ---
#> 116: 8 2.6583955 [rad] 696952.5 5508004 2.4662821 [rad]
#> 117: 9 -1.4177958 [rad] 697014.8 5507923 -2.9981952 [rad]
#> 118: 10 0.5336646 [rad] 697015.8 5507916 0.5103765 [rad]
#> 119: 11 -1.0819257 [rad] 697285.0 5508368 -1.1444566 [rad]
#> 120: 40 NA [rad] 696620.8 5508731 NA [rad]
#> position_group_direction rank_position_group_direction
#> <num> <num>
#> 1: -7.7690645 5
#> 2: 22.0744878 1
#> 3: -24.7063051 5
#> 4: 8.9025813 3
#> 5: -0.2458479 2
#> ---
#> 116: -21.9798928 6
#> 117: -31.1746472 6
#> 118: 22.8303115 1
#> 119: 26.1390093 1
#> 120: NA NA
#> geometry
#> <sfc_POINT>
#> 1: POINT (696191.5 5508362)
#> 2: POINT (696205.2 5508363)
#> 3: POINT (696745.8 5508225)
#> 4: POINT (696952 5508373)
#> 5: POINT (696079 5508218)
#> ---
#> 116: POINT (696996.5 5508024)
#> 117: POINT (697046.4 5507922)
#> 118: POINT (697037.5 5507924)
#> 119: POINT (697303 5508347)
#> 120: POINT (696616.7 5508736)
direction_step(DT = DT, id = 'ID')
#> direction column will be overwritten by this function
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group centroid_X centroid_Y group_direction position_group_direction
#> <int> <num> <num> <units> <num>
#> 1: 1 696214.3 5508342 0.5997289 [rad] -7.7690645
#> 2: 2 696228.1 5508344 1.7285069 [rad] 22.0744878
#> 3: 3 696760.4 5508245 0.9679820 [rad] -24.7063051
#> 4: 4 696965.7 5508380 -1.7070067 [rad] 8.9025813
#> 5: 5 696074.7 5508214 -0.8348445 [rad] -0.2458479
#> ---
#> 116: 8 696952.5 5508004 2.4662821 [rad] -21.9798928
#> 117: 9 697014.8 5507923 -2.9981952 [rad] -31.1746472
#> 118: 10 697015.8 5507916 0.5103765 [rad] 22.8303115
#> 119: 11 697285.0 5508368 -1.1444566 [rad] 26.1390093
#> 120: 40 696620.8 5508731 NA [rad] NA
#> rank_position_group_direction geometry direction
#> <num> <sfc_POINT> <units>
#> 1: 5 POINT (696191.5 5508362) 1.4903118 [rad]
#> 2: 1 POINT (696205.2 5508363) 1.7942728 [rad]
#> 3: 5 POINT (696745.8 5508225) 0.9220273 [rad]
#> 4: 3 POINT (696952 5508373) -1.7726867 [rad]
#> 5: 2 POINT (696079 5508218) -2.3533764 [rad]
#> ---
#> 116: 6 POINT (696996.5 5508024) 2.6583955 [rad]
#> 117: 6 POINT (697046.4 5507922) -1.4177958 [rad]
#> 118: 1 POINT (697037.5 5507924) 0.5336646 [rad]
#> 119: 1 POINT (697303 5508347) -1.0819257 [rad]
#> 120: NA POINT (696616.7 5508736) NA [rad]
centroid_group(DT)
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group centroid_X centroid_Y group_direction position_group_direction
#> <int> <num> <num> <units> <num>
#> 1: 1 696214.3 5508342 0.5997289 [rad] -7.7690645
#> 2: 2 696228.1 5508344 1.7285069 [rad] 22.0744878
#> 3: 3 696760.4 5508245 0.9679820 [rad] -24.7063051
#> 4: 4 696965.7 5508380 -1.7070067 [rad] 8.9025813
#> 5: 5 696074.7 5508214 -0.8348445 [rad] -0.2458479
#> ---
#> 116: 8 696952.5 5508004 2.4662821 [rad] -21.9798928
#> 117: 9 697014.8 5507923 -2.9981952 [rad] -31.1746472
#> 118: 10 697015.8 5507916 0.5103765 [rad] 22.8303115
#> 119: 11 697285.0 5508368 -1.1444566 [rad] 26.1390093
#> 120: 40 696620.8 5508731 NA [rad] NA
#> rank_position_group_direction geometry direction
#> <num> <sfc_POINT> <units>
#> 1: 5 POINT (696191.5 5508362) 1.4903118 [rad]
#> 2: 1 POINT (696205.2 5508363) 1.7942728 [rad]
#> 3: 5 POINT (696745.8 5508225) 0.9220273 [rad]
#> 4: 3 POINT (696952 5508373) -1.7726867 [rad]
#> 5: 2 POINT (696079 5508218) -2.3533764 [rad]
#> ---
#> 116: 6 POINT (696996.5 5508024) 2.6583955 [rad]
#> 117: 6 POINT (697046.4 5507922) -1.4177958 [rad]
#> 118: 1 POINT (697037.5 5507924) 0.5336646 [rad]
#> 119: 1 POINT (697303 5508347) -1.0819257 [rad]
#> 120: NA POINT (696616.7 5508736) NA [rad]
#> centroid
#> <sfc_POINT>
#> 1: POINT (696214.3 5508342)
#> 2: POINT (696228.1 5508344)
#> 3: POINT (696760.4 5508245)
#> 4: POINT (696965.7 5508380)
#> 5: POINT (696074.7 5508214)
#> ---
#> 116: POINT (696952.5 5508004)
#> 117: POINT (697014.8 5507923)
#> 118: POINT (697015.8 5507916)
#> 119: POINT (697285 5508368)
#> 120: POINT (696620.8 5508731)
direction_group(DT)
#> group_direction column will be overwritten by this function
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group centroid_X centroid_Y position_group_direction
#> <int> <num> <num> <num>
#> 1: 1 696214.3 5508342 -7.7690645
#> 2: 2 696228.1 5508344 22.0744878
#> 3: 3 696760.4 5508245 -24.7063051
#> 4: 4 696965.7 5508380 8.9025813
#> 5: 5 696074.7 5508214 -0.2458479
#> ---
#> 116: 8 696952.5 5508004 -21.9798928
#> 117: 9 697014.8 5507923 -31.1746472
#> 118: 10 697015.8 5507916 22.8303115
#> 119: 11 697285.0 5508368 26.1390093
#> 120: 40 696620.8 5508731 NA
#> rank_position_group_direction geometry direction
#> <num> <sfc_POINT> <units>
#> 1: 5 POINT (696191.5 5508362) 1.4903118 [rad]
#> 2: 1 POINT (696205.2 5508363) 1.7942728 [rad]
#> 3: 5 POINT (696745.8 5508225) 0.9220273 [rad]
#> 4: 3 POINT (696952 5508373) -1.7726867 [rad]
#> 5: 2 POINT (696079 5508218) -2.3533764 [rad]
#> ---
#> 116: 6 POINT (696996.5 5508024) 2.6583955 [rad]
#> 117: 6 POINT (697046.4 5507922) -1.4177958 [rad]
#> 118: 1 POINT (697037.5 5507924) 0.5336646 [rad]
#> 119: 1 POINT (697303 5508347) -1.0819257 [rad]
#> 120: NA POINT (696616.7 5508736) NA [rad]
#> centroid group_direction
#> <sfc_POINT> <units>
#> 1: POINT (696214.3 5508342) 0.5997289 [rad]
#> 2: POINT (696228.1 5508344) 1.7285069 [rad]
#> 3: POINT (696760.4 5508245) 0.9679820 [rad]
#> 4: POINT (696965.7 5508380) -1.7070067 [rad]
#> 5: POINT (696074.7 5508214) -0.8348445 [rad]
#> ---
#> 116: POINT (696952.5 5508004) 2.4662821 [rad]
#> 117: POINT (697014.8 5507923) -2.9981952 [rad]
#> 118: POINT (697015.8 5507916) 0.5103765 [rad]
#> 119: POINT (697285 5508368) -1.1444566 [rad]
#> 120: POINT (696620.8 5508731) NA [rad]
leader_direction_group(DT)
#> position_group_direction column will be overwritten by this function
#> rank_position_group_direction column will be overwritten by this function
#> ID X Y datetime population minutes timegroup
#> <char> <num> <num> <POSc> <int> <int> <int>
#> 1: A 696191.5 5508362 2017-01-17 00:00:47 1 0 1
#> 2: A 696205.2 5508363 2017-01-17 02:00:48 1 0 2
#> 3: A 696745.8 5508225 2017-01-17 04:00:48 1 0 3
#> 4: A 696952.0 5508373 2017-01-17 06:00:54 1 0 4
#> 5: A 696079.0 5508218 2017-01-17 08:00:54 1 0 5
#> ---
#> 116: J 696996.5 5508024 2017-01-17 14:00:42 1 0 8
#> 117: J 697046.4 5507922 2017-01-17 16:00:47 1 0 9
#> 118: J 697037.5 5507924 2017-01-17 18:00:54 1 0 10
#> 119: J 697303.0 5508347 2017-01-17 20:00:24 1 0 11
#> 120: J 696616.7 5508736 2017-01-17 22:00:42 1 0 12
#> group centroid_X centroid_Y geometry direction
#> <int> <num> <num> <sfc_POINT> <units>
#> 1: 1 696214.3 5508342 POINT (696191.5 5508362) 1.4903118 [rad]
#> 2: 2 696228.1 5508344 POINT (696205.2 5508363) 1.7942728 [rad]
#> 3: 3 696760.4 5508245 POINT (696745.8 5508225) 0.9220273 [rad]
#> 4: 4 696965.7 5508380 POINT (696952 5508373) -1.7726867 [rad]
#> 5: 5 696074.7 5508214 POINT (696079 5508218) -2.3533764 [rad]
#> ---
#> 116: 8 696952.5 5508004 POINT (696996.5 5508024) 2.6583955 [rad]
#> 117: 9 697014.8 5507923 POINT (697046.4 5507922) -1.4177958 [rad]
#> 118: 10 697015.8 5507916 POINT (697037.5 5507924) 0.5336646 [rad]
#> 119: 11 697285.0 5508368 POINT (697303 5508347) -1.0819257 [rad]
#> 120: 40 696620.8 5508731 POINT (696616.7 5508736) NA [rad]
#> centroid group_direction position_group_direction
#> <sfc_POINT> <units> <num>
#> 1: POINT (696214.3 5508342) 0.5997289 [rad] -7.7690645
#> 2: POINT (696228.1 5508344) 1.7285069 [rad] 22.0744878
#> 3: POINT (696760.4 5508245) 0.9679820 [rad] -24.7063051
#> 4: POINT (696965.7 5508380) -1.7070067 [rad] 8.9025813
#> 5: POINT (696074.7 5508214) -0.8348445 [rad] -0.2458479
#> ---
#> 116: POINT (696952.5 5508004) 2.4662821 [rad] -21.9798928
#> 117: POINT (697014.8 5507923) -2.9981952 [rad] -31.1746472
#> 118: POINT (697015.8 5507916) 0.5103765 [rad] 22.8303115
#> 119: POINT (697285 5508368) -1.1444566 [rad] 26.1390093
#> 120: POINT (696620.8 5508731) NA [rad] NA
#> rank_position_group_direction
#> <num>
#> 1: 5
#> 2: 1
#> 3: 5
#> 4: 3
#> 5: 2
#> ---
#> 116: 6
#> 117: 6
#> 118: 1
#> 119: 1
#> 120: NA