Skip to contents

spatsoc is an R package for detecting spatial and temporal groups in GPS relocations and measuring intragroup social dynamics. It can be used to convert GPS relocations to gambit-of-the-group format to build proximity-based social networks, identify nearest neighbours distances and direction, and measure individual's position with respect to the group centroid or group leader. See all available functions below, in the manual or on the acommpanying documentation website at https://docs.ropensci.org/spatsoc/.

Author

Maintainer: Alec L. Robitaille robit.alec@gmail.com (ORCID)

Authors: